package org.rexxla.bsf.engines.rexx;

import java.util.*;

/** Class to allow Rexx enumerating objects of classes implementing the Enumeration interface, if running under Java 1.1.
 *
 *  It turns out that on all Java versions (tested on Sun's Windows versions of: 1.1.8, 1.2.2,
 *  1.3.1_06, 1.4.1_01) &quot;<code>Method.invoke()</code>&quot; throws an &quot<code>IllegalAccessException</code>&quot;,
 *  if accessing public methods of inner classes. Java 1.5 does not allow identifiers to be named 'enum', hence renamed the
 *  variable.
 *
 * @author Rony G. Flatscher
 * @version 1.1.2, 2005-06-17
 * @since   2003-02-12 by rgf
 */
public class EnumerationWrapper implements Enumeration
{

    /** Private object storing the object to enumerate. */
    private Object enumObj;

    // public EnumerationWrapper (Object enumObject)
    public EnumerationWrapper (Enumeration enumObject)
    {
        this.enumObj=enumObject;
    }

    // Enumeration interface implementation
    /** Implements the interface {@link java.util.Enumeration#hasMoreElements() java.util.Enumeration.hasMoreElements()}.
     */
    public boolean hasMoreElements()
    {
        return ((Enumeration) enumObj).hasMoreElements();
    }

    /** Implements the interface {@link java.util.Enumeration#nextElement() java.util.Enumeration.nextElement()}.
     *
     * @exception NoSuchElementException raised, if using the Enumerator interface and moving
     *                                   beyond the end of the supplier object.
     */
    public Object nextElement()
    {
        return ((Enumeration) enumObj).nextElement();
    }
}
